import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Repository } from 'typeorm';
import { Album } from './album.entity';
import { CreateAlbumDto } from './dto/create-album.dto';
import { UpdateAlbumDto } from './dto/update-album.dto';

@Injectable()
export class AlbumService {
  constructor(
    @InjectRepository(Album)
    private albumRepository: Repository<Album>
  ) {}

  findAll(): Promise<Album[]> {
    return this.albumRepository.find();
  }

  findOneById(id: number): Promise<Album | null> {
    return this.albumRepository.findOneBy({ id: id });
  }

  async create(createAlbumDto: CreateAlbumDto): Promise<number> {
    const album = this.albumRepository.create({
      title: createAlbumDto.title,
      artist: createAlbumDto.artist,
      genre: createAlbumDto.genre
    });
    const savedAlbum = await this.albumRepository.save(album);
    return savedAlbum.id;
  }

  async update(updateAlbumDto: UpdateAlbumDto): Promise<string> {
    const album = this.albumRepository.findOneBy({ id: updateAlbumDto.id });
    if (!album)
      return "Album not found";

    await this.albumRepository.update({ id: updateAlbumDto.id }, {
      title: updateAlbumDto.title,
      artist: updateAlbumDto.artist,
      genre: updateAlbumDto.genre
    });
    return "Album updated successfully";
  }

  async remove(id: number): Promise<void> {
    await this.albumRepository.delete(id);
  }
}
